@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from construct import *
 from binascii import hexlify,unhexlify
-from .WTC_CodecTools import *
+from codec_Watteco.WTC_CodecTools import *
 
 # For debug ...
 class PrintContext(Construct):
